.. _all-salt_modules:

======================================
Full list of builtin execution modules
======================================

.. admonition:: Virtual modules

    .. toctree::

        salt.modules.pkg

.. currentmodule:: salt.modules

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    aliases
    alternatives
    apache
    aptpkg
    archive
    artifactory
    at
    augeas_cfg
    aws_sqs
    bamboohr
    beacons
    bigip
    blockdev
    bluez
    boto_asg
    boto_cfn
    boto_cloudwatch
    boto_dynamodb
    boto_ec2
    boto_elasticache
    boto_elb
    boto_iam
    boto_kms
    boto_rds
    boto_route53
    boto_secgroup
    boto_sns
    boto_sqs
    boto_vpc
    bower
    brew
    bridge
    bsd_shadow
    btrfs
    cabal
    cassandra
    cassandra_cql
    chassis
    chef
    chocolatey
    cloud
    cmdmod
    composer
    config
    consul
    container_resource
    cp
    cpan
    cron
    cyg
    daemontools
    darwin_pkgutil
    darwin_sysctl
    data
    ddns
    deb_apache
    deb_postgres
    debbuild
    debconfmod
    debian_ip
    debian_service
    defaults
    devmap
    dig
    disk
    djangomod
    dnsmasq
    dnsutil
    dockerio
    dockerng
    dpkg
    drac
    dracr
    drbd
    ebuild
    eix
    elasticsearch
    environ
    eselect
    esxi
    etcd_mod
    event
    extfs
    file
    firewalld
    freebsd_sysctl
    freebsdjail
    freebsdkmod
    freebsdpkg
    freebsdports
    freebsdservice
    gem
    genesis
    gentoo_service
    gentoolkitmod
    git
    glance
    glusterfs
    gnomedesktop
    gpg
    grains
    group
    groupadd
    grub_legacy
    guestfs
    hadoop
    haproxyconn
    hashutil
    hg
    hipchat
    hosts
    htpasswd
    http
    ifttt
    ilo
    img
    incron
    influx
    ini_manage
    inspectlib
    introspect
    ipmi
    ipset
    iptables
    jboss7
    jboss7_cli
    junos
    kerberos
    key
    keyboard
    keystone
    kmod
    launchctl
    layman
    ldapmod
    linux_acl
    linux_lvm
    linux_sysctl
    localemod
    locate
    logadm
    logrotate
    lvs
    lxc
    mac_group
    mac_user
    macports
    makeconf
    match
    mdadm
    memcached
    mine
    mod_random
    modjk
    mongodb
    monit
    moosefs
    mount
    mssql
    munin
    mysql
    nacl
    nagios
    nagios_rpc
    netbsd_sysctl
    netbsdservice
    netscaler
    network
    neutron
    nfs3
    nftables
    nginx
    node
    nova
    npm
    nspawn
    omapi
    openbsd_sysctl
    openbsdpkg
    openbsdrcctl
    openbsdservice
    openstack_config
    oracle
    osquery
    osxdesktop
    pacman
    pagerduty
    pagerduty_util
    pam
    parted
    pecl
    pillar
    pip
    pkg_resource
    pkgin
    pkgng
    pkgutil
    portage_config
    postfix
    postgres
    poudriere
    powerpath
    ps
    publish
    puppet
    pushover_notify
    pw_group
    pw_user
    pyenv
    qemu_img
    qemu_nbd
    quota
    rabbitmq
    raet_publish
    rallydev
    random_org
    rbenv
    rdp
    redismod
    reg
    rest_package
    rest_service
    ret
    rh_ip
    rh_service
    riak
    rpm
    rpmbuild
    rsync
    runit
    rvm
    s3
    saltcloudmod
    saltutil
    schedule
    scsi
    sdb
    seed
    selinux
    sensors
    serverdensity_device
    service
    shadow
    slack_notify
    slsutil
    smartos_imgadm
    smartos_virt
    smartos_vmadm
    smbios
    smf
    smtp
    softwareupdate
    solaris_group
    solaris_shadow
    solaris_user
    solarisips
    solarispkg
    solr
    splay
    splunk_search
    sqlite3
    ssh
    state
    status
    stormpath
    sudo
    supervisord
    svn
    swift
    sysbench
    syslog_ng
    sysmod
    sysrc
    system
    system_profiler
    systemd
    temp
    test
    test_virtual
    timezone
    tls
    tomcat
    trafficserver
    tuned
    twilio_notify
    udev
    upstart
    uptime
    user
    useradd
    uwsgi
    varnish
    vbox_guest
    victorops
    virt
    virtualenv_mod
    vsphere
    win_autoruns
    win_dacl
    win_disk
    win_dns_client
    win_file
    win_firewall
    win_groupadd
    win_ip
    win_network
    win_ntp
    win_path
    win_pkg
    win_powercfg
    win_repo
    win_servermanager
    win_service
    win_shadow
    win_status
    win_system
    win_timezone
    win_update
    win_useradd
    win_wua
    x509
    xapi
    xfs
    xmpp
    yumpkg
    zcbuildout
    zfs
    zk_concurrency
    znc
    zpool
    zypper
